@@ -75,8 +75,11 @@ class NeptuneExperimentTracker(ExperimentTracker):
         super().__init__(projectID, entityID, analysisName, **kwargs)
 
         self.apiToken = kwargs["apiToken"]
-        # if os.path.exists(".neptune/temp"):
-        #     shutil.rmtree(".neptune/temp")
+
+    def loadProject(self):
+        self.project = neptune.init_project(
+            name=self.entityID + "/" + self.projectID, api_token=self.apiToken
+        )
 
     def start(self, model):
         self.tracker = neptune.init(
